@@ -160,6 +160,7 @@ sensor_names
 ]
 """
 
+from collections import OrderedDict
 from fnmatch import fnmatch
 from json import loads
 
@@ -167,8 +168,7 @@ STRING_NOT_INSTALLED = "not installed"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 10
@@ -189,20 +189,18 @@ class Py3status:
         placeholders = self.py3.get_placeholders_list(self.format_sensor)
         format_sensor = {x: ":g" for x in placeholders if x != "name"}
         self.sensor_placeholders = [x for x in placeholders if x != "name"]
-        self.format_sensor = self.py3.update_placeholder_formats(
-            self.format_sensor, format_sensor
-        )
+        self.format_sensor = self.py3.update_placeholder_formats(self.format_sensor, format_sensor)
 
         self.first_run = True
 
         if self.chips:
             lm_sensors_data = self._get_lm_sensors_data()
-            chips = set()
+            chips = OrderedDict()
             for _filter in self.chips:
                 for chip_name in lm_sensors_data:
                     if fnmatch(chip_name, _filter):
-                        chips.add(_filter)
-            self.lm_sensors_command += chips
+                        chips[_filter] = None
+            self.lm_sensors_command += OrderedDict.keys(chips)
 
         self.sensors = {"list": [], "name": {}, "sensors": self.sensors}
 
@@ -228,7 +226,17 @@ class Py3status:
             self.thresholds_man.remove("auto.input")
 
     def _get_lm_sensors_data(self):
-        return loads(self.py3.command_output(self.lm_sensors_command))
+        output = self.py3.command_output(self.lm_sensors_command)
+        temporary = OrderedDict()
+
+        for chunk in output.strip().split("}\n{"):
+            if not chunk.startswith("{"):
+                chunk = "{" + chunk
+            if not chunk.endswith("}"):
+                chunk = chunk + "}"
+            temporary.update(loads(chunk))
+
+        return temporary
 
     def lm_sensors(self):
         lm_sensors_data = self._get_lm_sensors_data()
@@ -299,9 +307,7 @@ class Py3status:
                             auto_input.append((_crit, self.color_crit))
 
                     key = "{}/{}".format(chip["name"], sensor["name"])
-                    self.py3.threshold_get_color(
-                        _input, ("auto.input", key, auto_input)
-                    )
+                    self.py3.threshold_get_color(_input, ("auto.input", key, auto_input))
 
                 for x in self.sensor_placeholders:
                     if x not in sensor:
@@ -323,9 +329,7 @@ class Py3status:
 
         return {
             "cached_until": self.py3.time_in(self.cache_timeout),
-            "full_text": self.py3.safe_format(
-                self.format, {"format_chip": format_chip}
-            ),
+            "full_text": self.py3.safe_format(self.format, {"format_chip": format_chip}),
         }
 
 
