@@ -22,16 +22,13 @@ from socket import gethostname
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     format = "{username}"
 
     class Meta:
-        deprecated = {
-            "remove": [{"param": "cache_timeout", "msg": "obsolete parameter"}]
-        }
+        deprecated = {"remove": [{"param": "cache_timeout", "msg": "obsolete parameter"}]}
 
     def whoami(self):
         return {
